/*    patchlevel.h
 *
 *    Copyright (C) 1993, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
 *    2003, 2004, 2005, 2006, 2007, 2008, 2009, by Larry Wall and others
 *
 *    You may distribute under the terms of either the GNU General Public
 *    License or the Artistic License, as specified in the README file.
 *
 */

#ifndef __PATCHLEVEL_H_INCLUDED__

/* do not adjust the whitespace! Configure expects the numbers to be
 * exactly on the third column */

#define PERL_REVISION	5		/* age */
#define PERL_VERSION	28		/* epoch */
#define PERL_SUBVERSION	2		/* generation */

/* The following numbers describe the earliest compatible version of
   Perl ("compatibility" here being defined as sufficient binary/API
   compatibility to run XS code built with the older version).
   Normally this should not change across maintenance releases.

   Note that this only refers to an out-of-the-box build.  Many non-default
   options such as usemultiplicity tend to break binary compatibility
   more often.

   This is used by Configure et al to figure out
   PERL_INC_VERSION_LIST, which lists version libraries
   to include in @INC.  See INSTALL for how this works.

   Porting/bump-perl-version will automatically set these to the version of perl
   to be released for blead releases, and to 5.X.0 for maint releases. Manually
   changing them should not be necessary.
*/
#define PERL_API_REVISION	5
#define PERL_API_VERSION	28
#define PERL_API_SUBVERSION	0
/*
   XXX Note:  The selection of non-default Configure options, such
   as -Duselonglong may invalidate these settings.  Currently, Configure
   does not adequately test for this.   A.D.  Jan 13, 2000
*/

#define __PATCHLEVEL_H_INCLUDED__
#endif

/*
	local_patches -- list of locally applied less-than-subversion patches.
	If you're distributing such a patch, please give it a name and a
	one-line description, placed just before the last NULL in the array
	below.  If your patch fixes a bug in the perlbug database, please
	mention the bugid.  If your patch *IS* dependent on a prior patch,
	please place your applied patch line after its dependencies. This
	will help tracking of patch dependencies.

	Please either use 'diff --unified=0' if your diff supports
	that or edit the hunk of the diff output which adds your patch
	to this list, to remove context lines which would give patch
	problems. For instance, if the original context diff is

	   *** patchlevel.h.orig	<date here>
	   --- patchlevel.h	<date here>
	   *** 38,43 ***
	   --- 38,44 ---
	     	,"FOO1235 - some patch"
	     	,"BAR3141 - another patch"
	     	,"BAZ2718 - and another patch"
	   + 	,"MINE001 - my new patch"
	     	,NULL
	     };

	please change it to
	   *** patchlevel.h.orig	<date here>
	   --- patchlevel.h	<date here>
	   *** 41,43 ***
	   --- 41,44 ---
	   + 	,"MINE001 - my new patch"
	     	,NULL
	     };

	(Note changes to line numbers as well as removal of context lines.)
	This will prevent patch from choking if someone has previously
	applied different patches than you.

        History has shown that nobody distributes patches that also
        modify patchlevel.h. Do it yourself. The following perl
        program can be used to add a comment to patchlevel.h:

#!perl
die "Usage: perl -x patchlevel.h comment ..." unless @ARGV;
open PLIN, "<", "patchlevel.h" or die "Couldn't open patchlevel.h : $!";
open PLOUT, ">", "patchlevel.new" or die "Couldn't write on patchlevel.new : $!";
my $seen=0;
while (<PLIN>) {
    if (/\t,NULL/ and $seen) {
       while (my $c = shift @ARGV){
	    $c =~ s|\\|\\\\|g;
	    $c =~ s|"|\\"|g;
            print PLOUT qq{\t,"$c"\n};
       }
    }
    $seen++ if /local_patches\[\]/;
    print PLOUT;
}
close PLOUT or die "Couldn't close filehandle writing to patchlevel.new : $!";
close PLIN or die "Couldn't close filehandle reading from patchlevel.h : $!";
close DATA; # needed to allow unlink to work win32.
unlink "patchlevel.bak" or warn "Couldn't unlink patchlevel.bak : $!"
  if -e "patchlevel.bak";
rename "patchlevel.h", "patchlevel.bak" or
  die "Couldn't rename patchlevel.h to patchlevel.bak : $!";
rename "patchlevel.new", "patchlevel.h" or
  die "Couldn't rename patchlevel.new to patchlevel.h : $!";
__END__

Please keep empty lines below so that context diffs of this file do
not ever collect the lines belonging to local_patches() into the same
hunk.

 */

#if !defined(PERL_PATCHLEVEL_H_IMPLICIT) && !defined(LOCAL_PATCH_COUNT)
#  if defined(PERL_IS_MINIPERL)
#    define PERL_PATCHNUM "UNKNOWN-miniperl"
#    define PERL_GIT_UNPUSHED_COMMITS /*leave-this-comment*/
#  elif defined(PERL_MICRO)
#    define PERL_PATCHNUM "UNKNOWN-microperl"
#    define PERL_GIT_UNPUSHED_COMMITS /*leave-this-comment*/
#  else
#include "git_version.h"
#  endif
static const char * const local_patches[] = {
	NULL
#ifdef PERL_GIT_UNCOMMITTED_CHANGES
	,"uncommitted-changes"
#endif
	PERL_GIT_UNPUSHED_COMMITS    	/* do not remove this line */
	,"Fedora Patch1: Removes date check, Fedora/RHEL specific"
	,"Fedora Patch2: support for libdir64"
	,"Fedora Patch3: use libresolv instead of libbind"
	,"Fedora Patch4: USE_MM_LD_RUN_PATH"
	,"Fedora Patch5: Provide MM::maybe_command independently (bug #1129443)"
	,"Fedora Patch6: Dont run one io test due to random builder failures"
	,"Fedora Patch8: Define SONAME for libperl.so"
	,"Fedora Patch9: Install libperl.so to -Dshrpdir value"
	,"Fedora Patch10: Document Math::BigInt::CalcEmu requires Math::BigInt (CPAN RT#85015)"
	,"Fedora Patch11: Make *DBM_File desctructors thread-safe (RT#61912)"
	,"Fedora Patch12: Replace EU::MakeMaker dependency with EU::MM::Utils in IPC::Cmd (bug #1129443)"
	,"Fedora Patch13: Fix executing arybase::_tie_it() in Safe compartement (RT#131588)"
	,"Fedora Patch14: Link XS modules to pthread library to fix linking with -z defs"
	,"Fedora Patch17: Fix printing a warning about a wide character when matching a regular expression while ISO-8859-1 locale is in effect"
	,"Fedora Patch18: Fix invoking a check for wide characters while ISO-8859-1 locale is in effect"
	,"Fedora Patch20: Fix build conditions in locale.c"
	,"Fedora Patch21: Fix a file descriptor leak in in-place edits (RT#133314)"
	,"Fedora Patch23: Fix a buffer overrun in deprecated S_is_utf8_common()"
	,"Fedora Patch24: Fix a time race in Time-HiRes/t/itimer.t test"
	,"Fedora Patch26: Fix Time::Piece to handle objects in overloaded methods correctly"
	,"Fedora Patch27: Fix an assignment to a lexical variable in multiconcatenation expressions (RT#133441)"
	,"Fedora Patch28: Fix a spurious warning about uninitialized value in warn (RT#132683)"
	,"Fedora Patch30: Pass the correct CFLAGS to dtrace"
	,"Fedora Patch33: Fix PathTools tests to cope with ESTALE error (RT#133534)"
	,"Fedora Patch34: Fix an undefined behaviour in S_hv_delete_common()"
	,"Fedora Patch38: Fix compiling regular expressions that contain both compile- and run-time compiled code blocks (RT#133687)"
	,"Fedora Patch39: Adjust tests to gdbm-1.15 (RT#133295)"
	,"Fedora Patch44: Fix reporting a line number for non-terminated prototypes (RT#133524)"
	,"Fedora Patch45: Fix first eof() return value (RT#133721)"
	,"Fedora Patch49: Prevent long jumps from clobbering local variables (RT#133575)"
	,"Fedora Patch50: Fix a mismatch with a case-insesitive regular expression on a text with ligatures (RT#133756)"
	,"Fedora Patch53: Fix setting magic when changing $^R (RT#133782)"
	,"Fedora Patch54: Fix a race when loading XS modules"
	,"Fedora Patch56: Fix a leak when compiling a typed hash dereference"
	,"Fedora Patch58: Fix a buffer overread when handling a scope error in qr/\\(?{/ (RT#133879)"
	,"Fedora Patch59: Fix a buffer overread when parsing a regular expression with an unknown character name (RT#133880)"
	,"Fedora Patch60: Fix mbstate_t initialization in POSIX::mblen (RT#133928)"
	,"Fedora Patch61: Fix a memory leak when cloning a regular expression"
	,"Fedora Patch62: Fix a memory leak when spawning threads in a BEGIN phase"
	,"Fedora Patch63: Fix a memory leak when assigning a regular expression to a non-copy-on-write string"
	,"Fedora Patch64: Fix a memory leak when assignig to a localized ${^WARNING_BITS}"
	,"Fedora Patch65: Fix a memory leak when parsing misindented here-documents"
	,"Fedora Patch66: Fix a memory leak in package name lookup (RT#133977)"
	,"Fedora Patch68: Fix a memory leak when deletion in a tied hash dies"
	,"Fedora Patch69: Fix a crash when matching case insensitively (RT#133892)"
	,"Fedora Patch70: Fix a memory leak when warning about malformed UTF-8 string"
	,"Fedora Patch71: Do not panic when evaluating non-ASCII bare words (RT#134061)"
	,"Fedora Patch72: Do not panic when evaluating non-ASCII bare words (RT#134061)"
	,"Fedora Patch73: Fix a crash in SIGALARM handler when waiting on a child process to be closed (RT#122112)"
	,"Fedora Patch74: Fix a crash in SIGALARM handler when waiting on a child process to be closed (RT#122112)"
	,"Fedora Patch75: Fix a crash in SIGALARM handler when waiting on a child process to be closed (RT#122112)"
	,"Fedora Patch76: Fix a crash with a negative precision in sprintf function (RT#134008)"
	,"Fedora Patch77: Fix a crash with a negative precision in sprintf function (RT#134008)"
	,"Fedora Patch78: Prevent from wrapping a width in a numeric format string (RT#133913)"
	,"Fedora Patch79: Fix subroutine protypes to track reference aliases (RT#134072)"
	,"Fedora Patch80: Improve retrieving a scalar value of a variable modified in a signal handler (RT#134035)"
	,"Fedora Patch81: Fix changing packet destination sent from a UDP IO::Socket object (RT#133936)"
	,"Fedora Patch82: Fix changing packet destination sent from a UDP IO::Socket object (RT#133936)"
	,"Fedora Patch83: Fix changing packet destination sent from a UDP IO::Socket object (RT#133936)"
	,"Fedora Patch84: Fix a stack underflow in readline() if passed an empty array as an argument (#RT133989)"
	,"Fedora Patch85: Fix %{^CAPTURE_ALL} to be an alias for %- variable (RT#131867)"
	,"Fedora Patch86: Fix %{^CAPTURE} value when used after @{^CAPTURE} (RT#134193)"
	,"Fedora Patch87: Fix %{^CAPTURE} value when used after @{^CAPTURE} (RT#134193)"
	,"Fedora Patch88: Fix a test for a crash in SIGALARM handler when waiting on a child process to be closed (RT#122112)"
	,"Fedora Patch89: Fix a crash on an uninitialized warning when processing a multideref node (RT#134275)"
	,"Fedora Patch90: Preserve append mode when opening anonymous files (RT#134221)"
	,"Fedora Patch91: Preserve append mode when opening anonymous files (RT#134221)"
	,"Fedora Patch92: Preserve append mode when opening anonymous files (RT#134221)"
	,"Fedora Patch93: Fix propagating non-string variables in an exception value (RT#134291)"
	,"Fedora Patch94: Include trailing zero in scalars holding trie data (RT#134207)"
	,"Fedora Patch95: Fix a use after free in /(?{...})/ (RT#134208)"
	,"Fedora Patch96: Fix a use after free in debugging output of a collation"
	,"Fedora Patch97: Fix a NULL pointer dereference in PerlIOVia_pushed()"
	,"Fedora Patch98: Fix a crash when setting $@ on unwinding a call stack (RT#134266)"
	,"Fedora Patch99: Fix a documentation about a future API change"
	,"Fedora Patch100: Correct a misspelling in perlrebackslash documentation (RT#134395)"
	,"Fedora Patch101: Fix a memory leak when matching a UTF-8 regular expression (RT#134390)"
	,"Fedora Patch102: Fix a detection for futimes (RT#134432)"
	,"Fedora Patch103: Fix a detection for futimes (RT#134432)"
	,"Fedora Patch104: Avoid panic when last value of search-and-replace is tainted and UTF-8 (RT#134409)"
	,"Fedora Patch105: Fix overloading for binary and octal floats (RT#125557)"
	,"Fedora Patch106: Fix handling undefined array members in Dumpvalue (RT#134441)"
	,"Fedora Patch107: Fix taint mode documentation regarding @INC"
	,"Fedora Patch108: Fix taint mode documentation regarding @INC"
	,"Fedora Patch109: Fix handling a layer argument in Tie::StdHandle::BINMODE() (RT#132475)"
	,"Fedora Patch110: Fix an unintended upgrade to UTF-8 in the middle of a transliteration"
	,"Fedora Patch111: Fix an unintended upgrade to UTF-8 in the middle of a transliteration"
	,"Fedora Patch112: Fix a race in File::stat() tests (GH#17234)"
	,"Fedora Patch113: Fix GCC 10 version detection (GH#17295)"
	,"Fedora Patch114: Fix a memory leak when compiling a regular expression with a non-word class (GH#17218)"
	,"Fedora Patch115: Fix Time-Local tests to pass after year 2019 (CPAN RT#124787)"
	,"Fedora Patch116: Work around a glibc bug in caching LC_MESSAGES (GH#17081)"
	,"Fedora Patch117: Fix POSIX:setlocale() documentation"
	,"Fedora Patch118: Prevent from an integer overflow in POSIX::SigSet()"
	,"Fedora Patch119: Fix thread-safety of IO::Handle (GH#14816)"
	,"Fedora Patch120: Fix thread-safety of IO::Handle (GH#14816)"
	,"Fedora Patch121: Fix thread-safety of IO::Handle (GH#14816)"
	,"Fedora Patch122: Close :unix PerlIO layers properly"
	,"Fedora Patch123: Fix counting a recursion limit when matching in a postponed eval (GH#17490)"
	,"Fedora Patch124: Only install ExtUtils::XSSymSet manual page on VMS (GH#17424)"
	,"Fedora Patch125: Fix sorting tied arrays (GH#17496)"
	,"Fedora Patch126: Fix sorting tied arrays (GH#17496)"
	,"Fedora Patch127: Fix a spurious warning about a multidimensional syntax (GH#16535)"
	,"Fedora Patch128: Fix a warning about an uninitialized value in B::Deparse (GH#17537)"
	,"Fedora Patch200: Link XS modules to libperl.so with EU::CBuilder on Linux"
	,"Fedora Patch201: Link XS modules to libperl.so with EU::MM on Linux"
	,NULL
};



/* Initial space prevents this variable from being inserted in config.sh  */
#  define	LOCAL_PATCH_COUNT	\
	((int)(C_ARRAY_LENGTH(local_patches)-2))

/* the old terms of reference, add them only when explicitly included */
#define PATCHLEVEL		PERL_VERSION
#undef  SUBVERSION		/* OS/390 has a SUBVERSION in a system header */
#define SUBVERSION		PERL_SUBVERSION
#endif
